==> deepin-home_1.0.6.orig.tar.xz: deepin-home-1.0.6/translations/deepin-home/az.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="az">
<context>
    <name>Card1</name>
    <message>
        <location filename="../src/maincomponentplugin/index/Card1.qml" line="88"/>
        <source>Coming</source>
        <translation>Tezliklə</translation>
    </message>
</context>
<context>
    <name>Index</name>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="50"/>
        <source>Communication</source>
        <translation>Kommunikasiya</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="51"/>
        <source>Discuss and share here</source>
        <translation>Burada müzakirə edin və paylaşın</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="60"/>
        <source>Bug Report</source>
        <translation>Xəta bidirişi</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="61"/>
        <source>Report issues you found</source>
        <translation>Tapdığınız xıtaları bioldirin</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="68"/>
        <source>Suggestions</source>
        <translation>Təkliflər</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="69"/>
        <source>Submit your suggestions</source>
        <translation>Təkliflərinizi bildirin</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="83"/>
        <source>Resources</source>
        <translation>Mənbələr</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="88"/>
        <source>Questionaire</source>
        <translation>Anket</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="145"/>
        <source>Join US</source>
        <translation>Bizə qoşul</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="150"/>
        <source>Internal Testing</source>
        <translation>Daxili sınama</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="163"/>
        <source>Community News</source>
        <translation>Cəmiyytin xəbərləri</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="278"/>
        <source>Network error, please try later</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>List</name>
    <message>
        <location filename="../src/maincomponentplugin/list/List.qml" line="40"/>
        <source>Messages</source>
        <translation>İsmarıclar</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/List.qml" line="43"/>
        <source>Questionaires</source>
        <translation>Anket</translation>
    </message>
</context>
<context>
    <name>MyTitleBar</name>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="26"/>
        <source>Launch at system startup</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="32"/>
        <source>About</source>
        <translation>Haqında</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="36"/>
        <source>Exit</source>
        <translation>Çıxış</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="46"/>
        <source>Version: %1</source>
        <translation>Versiya: %1</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="47"/>
        <source>Deepin Messages</source>
        <translation>Depin ismarıcları</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="83"/>
        <source>Unlogged</source>
        <translation>Qeydiyyatdan çıxarıldı</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="118"/>
        <source>Sign in</source>
        <translation>Daxil ol</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="130"/>
        <source>Sign out</source>
        <translation>Çıxın</translation>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <location filename="../src/maincomponentplugin/list/Notify.qml" line="51"/>
        <source>No messages yet.</source>
        <translation>Hələlik heç bir ismarıc yoxdur.</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Notify.qml" line="148"/>
        <source>%1 messages</source>
        <translation>%1 ismarıc var</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Notify.qml" line="152"/>
        <source>Mark all as read</source>
        <translation>Hamısını oxunmuş kimi işarələ.</translation>
    </message>
</context>
<context>
    <name>NotifyDetail</name>
    <message>
        <location filename="../src/maincomponentplugin/list/NotifyDetail.qml" line="65"/>
        <source>View more</source>
        <translation>Daha çox göstərmək</translation>
    </message>
</context>
<context>
    <name>Questionnaire</name>
    <message>
        <location filename="../src/maincomponentplugin/list/Questionnaire.qml" line="43"/>
        <source>No questionaires yet.</source>
        <translation>Hələlik heç bir anket yoxdur.</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Questionnaire.qml" line="88"/>
        <source>Expired on: %1</source>
        <translation>Bitmə vaxctı: %1</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Questionnaire.qml" line="116"/>
        <source>Fill In</source>
        <translation>Doldurun</translation>
    </message>
</context>
</TS>

==> deepin-home_1.0.15.orig.tar.xz: deepin-home-1.0.15/translations/deepin-home/az.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="az">
<context>
    <name>Card1</name>
    <message>
        <location filename="../src/maincomponentplugin/index/Card1.qml" line="88"/>
        <source>Coming</source>
        <translation>Tezliklə</translation>
    </message>
</context>
<context>
    <name>Index</name>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="51"/>
        <source>Communication</source>
        <translation>Kommunikasiya</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="52"/>
        <source>Discuss and share here</source>
        <translation>Burada müzakirə edin və paylaşın</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="61"/>
        <source>Bug Report</source>
        <translation>Xəta bidirişi</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="62"/>
        <source>Report issues you found</source>
        <translation>Tapdığınız xıtaları bioldirin</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="69"/>
        <source>Suggestions</source>
        <translation>Təkliflər</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="70"/>
        <source>Submit your suggestions</source>
        <translation>Təkliflərinizi bildirin</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="84"/>
        <source>Resources</source>
        <translation>Mənbələr</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="89"/>
        <source>Questionaire</source>
        <translation>Anket</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="146"/>
        <source>Join US</source>
        <translation>Bizə qoşul</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="151"/>
        <source>Internal Testing</source>
        <translation>Daxili sınama</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="165"/>
        <source>Community News</source>
        <translation>Cəmiyytin xəbərləri</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/index/Index.qml" line="282"/>
        <source>Network error, please try later</source>
        <translation>Şəbəkə xətası, sonra yenidən cəhd edin</translation>
    </message>
</context>
<context>
    <name>List</name>
    <message>
        <location filename="../src/maincomponentplugin/list/List.qml" line="40"/>
        <source>Messages</source>
        <translation>İsmarıclar</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/List.qml" line="43"/>
        <source>Questionaires</source>
        <translation>Anket</translation>
    </message>
</context>
<context>
    <name>MyTitleBar</name>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="26"/>
        <source>Launch at system startup</source>
        <translation>Sistem açılışı ilə birlikdə işə salmaq</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="32"/>
        <source>About</source>
        <translation>Haqında</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="36"/>
        <source>Exit</source>
        <translation>Çıxış</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="46"/>
        <source>Version: %1</source>
        <translation>Versiya: %1</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="47"/>
        <source>Deepin Home</source>
        <translation>Deepin Evi</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="83"/>
        <source>Unlogged</source>
        <translation>Qeydiyyatdan çıxarıldı</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="119"/>
        <source>Sign in</source>
        <translation>Daxil ol</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/titlebar/MyTitleBar.qml" line="131"/>
        <source>Sign out</source>
        <translation>Çıxın</translation>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <location filename="../src/maincomponentplugin/list/Notify.qml" line="51"/>
        <source>No messages yet.</source>
        <translation>Hələlik heç bir ismarıc yoxdur.</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Notify.qml" line="149"/>
        <source>%1 messages</source>
        <translation>%1 ismarıc var</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Notify.qml" line="153"/>
        <source>Mark all as read</source>
        <translation>Hamısını oxunmuş kimi işarələ.</translation>
    </message>
</context>
<context>
    <name>NotifyDetail</name>
    <message>
        <location filename="../src/maincomponentplugin/list/NotifyDetail.qml" line="65"/>
        <source>View more</source>
        <translation>Daha çox göstərmək</translation>
    </message>
</context>
<context>
    <name>Preload</name>
    <message>
        <location filename="../src/preloadplugin/Preload.qml" line="36"/>
        <source>Deepin Home</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Questionnaire</name>
    <message>
        <location filename="../src/maincomponentplugin/list/Questionnaire.qml" line="43"/>
        <source>No questionaires yet.</source>
        <translation>Hələlik heç bir anket yoxdur.</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Questionnaire.qml" line="89"/>
        <source>Expired on: %1</source>
        <translation>Bitmə vaxctı: %1</translation>
    </message>
    <message>
        <location filename="../src/maincomponentplugin/list/Questionnaire.qml" line="117"/>
        <source>Fill In</source>
        <translation>Doldurun</translation>
    </message>
</context>
</TS>
